<!-- DOC_TYPE: TRACKING -->

# Changelog

## Unreleased

### Added

- Initial EN/RU architecture documentation for runtime modules: `core`, `system`, `notifications`, `booking`, `cabinet`, `showcase`
- Initial EN/RU dedicated CLI architecture subtree with pages for entrypoints, blueprints, engine, commands, and project output
- GitHub-friendly `README.md` index pages for documentation subfolders
